.. _release_notes:

Release Notes
*************

The following are release notes used on `PyPI
<https://pypi.python.org/pypi/translate-toolkit>`_, `Sourceforge
<http://sourceforge.net/projects/translate/files/Translate%20Toolkit/>`_ and
mailing lists for Translate Toolkit releases.

.. toctree::
   :maxdepth: 1

   1.13.0-rc1 <1.13.0-rc1>
   1.12.0 <1.12.0>
   1.12.0-rc1 <1.12.0-rc1>
   1.11.0 <1.11.0>
   1.11.0-rc1 <1.11.0-rc1>
   1.10.0 <1.10.0>
   1.9.0 <1.9.0>
   1.8.1 <1.8.1>
